@@ -6,28 +6,28 @@ from moloni.base.helpers import endpoint, fill_query_params, validate_data
 
 
 class Associated_documents(BaseModel):
-    associated_id: str
-    value: str
+    associated_id: Optional[Union[str, int]] = None
+    value: Optional[Union[str, int]] = None
 
 
 class Payments(BaseModel):
-    date: str
-    notes: str
-    payment_method_id: str
-    value: str
+    date: Optional[Union[str, int]] = None
+    notes: Optional[Union[str, int]] = None
+    payment_method_id: Optional[Union[str, int]] = None
+    value: Optional[Union[str, int]] = None
 
 
 class Products(BaseModel):
-    discount: str
-    exemption_reason: str
-    name: str
-    order: str
-    price: str
-    product_id: str
-    qty: str
-    summary: str
-    taxes: str
-    warehouse_id: str
+    discount: Optional[Union[str, int]] = None
+    exemption_reason: Optional[Union[str, int]] = None
+    name: Optional[Union[str, int]] = None
+    order: Optional[Union[str, int]] = None
+    price: Optional[Union[str, int]] = None
+    product_id: Optional[Union[str, int]] = None
+    qty: Optional[Union[str, int]] = None
+    summary: Optional[Union[str, int]] = None
+    taxes: Optional[Union[str, int]] = None
+    warehouse_id: Optional[Union[str, int]] = None
 
 
 class InvoicesCountModel(BaseModel):
